bayespy.inference.vmp.nodes.poisson.PoissonDistribution.compute_mask_to_parent
==============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.poisson

.. automethod:: PoissonDistribution.compute_mask_to_parent